@@ -12,16 +12,10 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn key_input(
-        &mut self,
-        window: &wita::Window,
-        code: wita::KeyCode,
-        state: wita::KeyState,
-        _: bool,
-    ) {
-        if state == wita::KeyState::Pressed {
-            if let wita::VirtualKey::Char(_) = code.vkey {
-                window.close();
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.state == wita::KeyState::Pressed {
+            if let wita::VirtualKey::Char(_) = ev.key_code.vkey {
+                ev.window.close();
             }
         }
     }
