@@ -2,7 +2,7 @@ struct Application;
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .title("wita icon")
             .icon(wita::Icon::from_path("examples/icon.ico"))
             .build()?;
