@@ -1,4 +1,4 @@
-use crate::{device::*, event::EventHandler, event::OtherParams, window::LocalWindow};
+use crate::{device::*, event, event::EventHandler, window::LocalWindow};
 use std::any::Any;
 use std::cell::RefCell;
 use std::panic::resume_unwind;
@@ -163,7 +163,7 @@ where
                 .unwrap()
                 .downcast_mut::<T>()
                 .unwrap();
-            let ret = event_handler.other(&OtherParams {
+            let ret = event_handler.other(event::Other {
                 hwnd,
                 message,
                 wparam,
