@@ -1,8 +1,8 @@
 use crate::geometry::*;
 #[cfg(feature = "serde")]
 use serde::{de::*, *};
-use windows::Win32::{Foundation::*, UI::Input::KeyboardAndMouse::*, UI::WindowsAndMessaging::*};
 use windows::core::PCWSTR;
+use windows::Win32::{Foundation::*, UI::Input::KeyboardAndMouse::*, UI::WindowsAndMessaging::*};
 
 /// Describes the state of a keyboard key and a mouse button.
 #[derive(Clone, Copy, PartialEq, Eq, Debug, Hash)]
@@ -514,7 +514,7 @@ impl Default for Cursor {
 
 /// Describes a mouse wheel axis.
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
-pub enum Wheel {
+pub enum MouseWheelAxis {
     Vertical,
     Horizontal,
 }
