@@ -21,7 +21,7 @@
 //! }
 //!
 //! impl wita::EventHandler for Application {
-//!     fn closed(&mut self, _: &wita::Window) {
+//!     fn closed(&mut self, _: wita::event::Closed) {
 //!         println!("closed");
 //!     }
 //! }
@@ -48,7 +48,7 @@
 //! impl wita::EventHandler for Foo {
 //!     // You define handlers.
 //!     // For example, handle the event that closed the window.
-//!     fn closed(&mut self, _: &wita::Window) {
+//!     fn closed(&mut self, _: wita::event::Closed) {
 //!         // write handling codes
 //!     }
 //! }
@@ -70,7 +70,7 @@
 mod api;
 mod context;
 mod device;
-mod event;
+pub mod event;
 mod geometry;
 pub mod ime;
 mod monitor;
@@ -88,7 +88,8 @@ pub use device::WHEEL_DELTA;
 pub use device::*;
 #[doc(inline)]
 pub use error::ApiError;
-pub use event::*;
+#[doc(inline)]
+pub use event::EventHandler;
 pub use geometry::*;
 pub use monitor::*;
 pub use resource::*;
