@@ -1,13 +1,15 @@
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
-use crate::{api::*, context::*, device::*, event::EventHandler, geometry::*, ime, window::Window};
+use crate::{
+    api::*, context::*, device::*, event, event::EventHandler, geometry::*, ime, window::Window,
+};
 use std::panic::catch_unwind;
 use std::path::PathBuf;
+use windows::core::PWSTR;
 use windows::Win32::{
     Foundation::*, Graphics::Gdi::*, UI::Controls::WM_MOUSELEAVE, UI::HiDpi::*, UI::Input::Ime::*,
     UI::Input::KeyboardAndMouse::*, UI::Shell::*, UI::WindowsAndMessaging::*,
 };
-use windows::core::PWSTR;
 
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
 #[repr(usize)]
@@ -95,22 +97,23 @@ fn mouse_input<T: EventHandler + 'static>(
     call_handler(|eh: &mut T, state| {
         let buttons = &mut state.mouse_buttons;
         update_buttons(buttons, wparam);
-        eh.mouse_input(
+        let ev = event::MouseInput {
             window,
             button,
             button_state,
-            MouseState {
+            mouse_state: MouseState {
                 position: lparam_to_point(lparam),
                 buttons,
             },
-        );
+        };
+        eh.mouse_input(ev);
     });
     LRESULT(0)
 }
 
 fn mouse_wheel<T: EventHandler + 'static>(
     window: &Window,
-    dir: Wheel,
+    dir: MouseWheelAxis,
     wparam: WPARAM,
     lparam: LPARAM,
 ) -> LRESULT {
@@ -118,15 +121,16 @@ fn mouse_wheel<T: EventHandler + 'static>(
         let delta = hiword(wparam.0 as _);
         let buttons = &mut state.mouse_buttons;
         update_buttons(buttons, wparam);
-        eh.mouse_wheel(
+        let ev = event::MouseWheel {
             window,
-            dir,
-            delta as i32,
-            MouseState {
+            axis: dir,
+            distance: delta as i32,
+            mouse_state: MouseState {
                 position: lparam_to_point(lparam),
                 buttons,
             },
-        );
+        };
+        eh.mouse_wheel(ev);
     });
     LRESULT(0)
 }
@@ -139,12 +143,13 @@ fn key_input<T: EventHandler + 'static>(
 ) -> LRESULT {
     let scan_code = ScanCode(((lparam.0 >> 16) & 0x7f) as u32);
     call_handler(|eh: &mut T, _| {
-        eh.key_input(
+        let ev = event::KeyInput {
             window,
-            KeyCode::new(as_virtual_key(VIRTUAL_KEY(wparam.0 as _)), scan_code),
+            key_code: KeyCode::new(as_virtual_key(VIRTUAL_KEY(wparam.0 as _)), scan_code),
             state,
-            (lparam.0 >> 30) & 0x01 != 0,
-        );
+            prev_pressed: (lparam.0 >> 30) & 0x01 != 0,
+        };
+        eh.key_input(ev);
     });
     LRESULT(0)
 }
@@ -166,7 +171,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             WM_PAINT => {
                 let mut ps = PAINTSTRUCT::default();
                 BeginPaint(hwnd, &mut ps);
-                call_handler(|eh: &mut T, _| eh.draw(handle));
+                call_handler(|eh: &mut T, _| eh.draw(event::Draw { window: handle }));
                 EndPaint(hwnd, &ps);
                 LRESULT(0)
             }
@@ -184,21 +189,21 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                             dwHoverTime: 0,
                         });
                         state.entered_window = Some(window.clone());
-                        eh.cursor_entered(
-                            handle,
-                            MouseState {
+                        eh.cursor_entered(event::CursorEntered {
+                            window: handle,
+                            mouse_state: MouseState {
                                 position,
                                 buttons: &state.mouse_buttons,
                             },
-                        );
+                        });
                     } else {
-                        eh.cursor_moved(
-                            handle,
-                            MouseState {
+                        eh.cursor_moved(event::CursorMoved {
+                            window: handle,
+                            mouse_state: MouseState {
                                 position,
                                 buttons: &state.mouse_buttons,
                             },
-                        );
+                        });
                     }
                 });
                 let wnd = handle.state.read().unwrap();
@@ -211,13 +216,13 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     update_buttons(&mut state.mouse_buttons, wparam);
                     let mut pos = POINT::default();
                     GetCursorPos(&mut pos);
-                    eh.cursor_leaved(
-                        handle,
-                        MouseState {
+                    eh.cursor_leaved(event::CursorLeaved {
+                        window: handle,
+                        mouse_state: MouseState {
                             position: PhysicalPosition::new(pos.x, pos.y),
                             buttons: &mut state.mouse_buttons,
                         },
-                    );
+                    });
                 });
                 LRESULT(0)
             }
@@ -273,14 +278,14 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 wparam,
                 lparam,
             ),
-            WM_MOUSEWHEEL => mouse_wheel::<T>(handle, Wheel::Vertical, wparam, lparam),
-            WM_MOUSEHWHEEL => mouse_wheel::<T>(handle, Wheel::Horizontal, wparam, lparam),
+            WM_MOUSEWHEEL => mouse_wheel::<T>(handle, MouseWheelAxis::Vertical, wparam, lparam),
+            WM_MOUSEHWHEEL => mouse_wheel::<T>(handle, MouseWheelAxis::Horizontal, wparam, lparam),
             WM_KEYDOWN => key_input::<T>(handle, KeyState::Pressed, wparam, lparam),
             WM_KEYUP => key_input::<T>(handle, KeyState::Released, wparam, lparam),
             WM_CHAR => {
                 call_handler(|eh: &mut T, _| {
                     if let Some(c) = std::char::from_u32(wparam.0 as u32) {
-                        eh.char_input(handle, c);
+                        eh.char_input(event::CharInput { window: handle, c });
                     }
                 });
                 LRESULT(0)
@@ -317,7 +322,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     }
                 }
                 call_handler(|eh: &mut T, _| {
-                    eh.ime_start_composition(handle);
+                    eh.ime_start_composition(event::ImeStartComposition { window: handle });
                 });
                 DefWindowProcW(hwnd, msg, wparam, lparam)
             }
@@ -325,28 +330,28 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 call_handler(|eh: &mut T, _| {
                     let imc = ime::Imc::get(hwnd);
                     if (lparam.0 as u32) & GCS_COMPSTR != 0 {
-                        if let Some(ime::CompositionString::CompStr(s)) =
-                            imc.get_composition_string(GCS_COMPSTR)
-                        {
-                            if let Some(ime::CompositionString::CompAttr(attrs)) =
-                                imc.get_composition_string(GCS_COMPATTR)
-                            {
-                                eh.ime_composition(
-                                    handle,
-                                    &ime::Composition::new(s, attrs),
-                                    imc.get_candidate_list().as_ref(),
-                                );
+                        let result_str = imc.get_composition_string(GCS_COMPSTR);
+                        if let Some(ime::CompositionString::CompStr(s)) = result_str {
+                            let comp_str = imc.get_composition_string(GCS_COMPATTR);
+                            if let Some(ime::CompositionString::CompAttr(attrs)) = comp_str {
+                                eh.ime_composition(event::ImeComposition {
+                                    window: handle,
+                                    composition: &ime::Composition::new(s, attrs),
+                                    candidate_list: imc.get_candidate_list().as_ref(),
+                                });
                             }
                         }
                     }
                     if (lparam.0 as u32) & GCS_RESULTSTR != 0 {
-                        if let Some(ime::CompositionString::ResultStr(s)) =
-                            imc.get_composition_string(GCS_RESULTSTR)
-                        {
-                            if let Some(ime::CompositionString::CompAttr(attrs)) =
-                                imc.get_composition_string(GCS_COMPATTR)
-                            {
-                                eh.ime_composition(handle, &ime::Composition::new(s, attrs), None);
+                        let result_str = imc.get_composition_string(GCS_RESULTSTR);
+                        if let Some(ime::CompositionString::ResultStr(s)) = result_str {
+                            let comp_str = imc.get_composition_string(GCS_COMPATTR);
+                            if let Some(ime::CompositionString::CompAttr(attrs)) = comp_str {
+                                eh.ime_composition(event::ImeComposition {
+                                    window: handle,
+                                    composition: &ime::Composition::new(s, attrs),
+                                    candidate_list: None,
+                                });
                             }
                         }
                     }
@@ -370,16 +375,23 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     } else {
                         None
                     };
-                    eh.ime_end_composition(handle, ret);
+                    let ev = event::ImeEndComposition {
+                        window: handle,
+                        result: ret,
+                    };
+                    eh.ime_end_composition(ev);
                 });
                 DefWindowProcW(hwnd, msg, wparam, lparam)
             }
             WM_ACTIVATE => {
-                if ((wparam.0 as u32) & WA_ACTIVE) != 0 || ((wparam.0 as u32) & WA_CLICKACTIVE) != 0
-                {
-                    call_handler(|eh: &mut T, _| eh.activated(handle));
+                let active = ((wparam.0 as u32) & WA_ACTIVE) != 0;
+                let click_active = ((wparam.0 as u32) & WA_CLICKACTIVE) != 0;
+                if active || click_active {
+                    call_handler(|eh: &mut T, _| eh.activated(event::Activated { window: handle }));
                 } else {
-                    call_handler(|eh: &mut T, _| eh.inactivated(handle));
+                    call_handler(|eh: &mut T, _| {
+                        eh.inactivated(event::Inactivated { window: handle })
+                    });
                 }
                 LRESULT(0)
             }
@@ -388,9 +400,15 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 let size = PhysicalSize::new(loword(value as _) as u32, hiword(value as _) as u32);
                 call_handler(|eh: &mut T, state| {
                     if state.resizing {
-                        eh.resizing(handle, size);
+                        eh.resizing(event::Resizing {
+                            window: handle,
+                            size,
+                        });
                     } else {
-                        eh.resized(handle, size);
+                        eh.resized(event::Resized {
+                            window: handle,
+                            size,
+                        });
                     }
                 });
                 LRESULT(0)
@@ -399,7 +417,10 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 let pos = &*(lparam.0 as *const WINDOWPOS);
                 if pos.flags & SWP_NOMOVE == SET_WINDOW_POS_FLAGS(0) {
                     call_handler(|eh: &mut T, _| {
-                        eh.moved(handle, ScreenPosition::new(pos.x, pos.y))
+                        eh.moved(event::Moved {
+                            window: handle,
+                            position: ScreenPosition::new(pos.x, pos.y),
+                        });
                     });
                 }
                 DefWindowProcW(hwnd, msg, wparam, lparam)
@@ -411,7 +432,12 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             WM_EXITSIZEMOVE => {
                 set_resizing(false);
                 let size = handle.inner_size();
-                call_handler(|eh: &mut T, _| eh.resized(handle, size));
+                call_handler(|eh: &mut T, _| {
+                    eh.resized(event::Resized {
+                        window: handle,
+                        size,
+                    })
+                });
                 DefWindowProcW(hwnd, msg, wparam, lparam)
             }
             WM_DPICHANGED => {
@@ -428,7 +454,12 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     SWP_NOZORDER | SWP_NOACTIVATE,
                 );
                 let new_dpi = hiword(wparam.0 as _) as u32;
-                call_handler(|eh: &mut T, _| eh.dpi_changed(handle, new_dpi));
+                call_handler(|eh: &mut T, _| {
+                    eh.dpi_changed(event::DpiChanged {
+                        window: handle,
+                        new_dpi,
+                    })
+                });
                 let prev_size = prev_rc.right - prev_rc.left;
                 let next_size = rc.right - rc.left;
                 let children = child_windows(hwnd);
@@ -471,7 +502,12 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                         SWP_NOACTIVATE | SWP_NOZORDER,
                     );
                     if let Some(child) = find_window(child) {
-                        call_handler(|eh: &mut T, _| eh.dpi_changed(&child.handle, new_dpi));
+                        call_handler(|eh: &mut T, _| {
+                            eh.dpi_changed(event::DpiChanged {
+                                window: &child.handle,
+                                new_dpi,
+                            })
+                        });
                     }
                 }
                 LRESULT(0)
@@ -513,7 +549,11 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 let mut pt = POINT::default();
                 DragQueryPoint(hdrop, &mut pt);
                 call_handler(|eh: &mut T, _| {
-                    eh.drop_files(handle, &files_ref, PhysicalPosition::new(pt.x, pt.y));
+                    eh.drop_files(event::DropFiles {
+                        window: handle,
+                        paths: &files_ref,
+                        position: PhysicalPosition::new(pt.x, pt.y),
+                    });
                 });
                 DragFinish(hdrop);
                 LRESULT(0)
@@ -528,7 +568,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     state.closed = true;
                 }
                 call_handler(|eh: &mut T, _| {
-                    eh.closed(handle);
+                    eh.closed(event::Closed { window: handle });
                     {
                         let state = handle.state.read().unwrap();
                         for child in state.children.iter() {
