@@ -10,11 +10,11 @@ use std::cell::RefCell;
 use std::mem::size_of;
 use std::ptr::null_mut;
 use std::rc::Rc;
+use windows::core::{PCSTR, PCWSTR, PSTR};
 use windows::Win32::{
     Devices::HumanInterfaceDevice::*, Foundation::*, Storage::FileSystem::*,
     UI::Input::KeyboardAndMouse::*, UI::Input::*, UI::WindowsAndMessaging::*,
 };
-use windows::core::{PSTR, PCSTR, PCWSTR};
 
 const HID_USAGE_PAGE_GENERIC: u16 = 0x01;
 
@@ -835,7 +835,10 @@ where
             _ => unreachable!(),
         };
         if let Some(data) = data {
-            eh.raw_input(window, &data);
+            eh.raw_input(crate::event::RawInput {
+                window,
+                data: &data,
+            });
         }
     });
     DefWindowProcW(hwnd, WM_INPUT, wparam, lparam)
@@ -875,7 +878,11 @@ where
             }
             DEVICE_LIST.with(|dl| dl.borrow_mut().push(device.clone()));
             call_handler(|eh: &mut T, _| {
-                eh.raw_input_device_change(window, &device, DeviceChangeState::Arrival);
+                eh.raw_input_device_change(crate::event::RawInputDeviceChange {
+                    window,
+                    device: &device,
+                    state: DeviceChangeState::Arrival,
+                });
             });
             debug!("device arrival: {:?} {:?}", handle, device.name);
         }
@@ -887,7 +894,11 @@ where
                     .cloned()
             }) {
                 call_handler(|eh: &mut T, _| {
-                    eh.raw_input_device_change(window, &device, DeviceChangeState::Removal);
+                    eh.raw_input_device_change(crate::event::RawInputDeviceChange {
+                        window,
+                        device: &device,
+                        state: DeviceChangeState::Removal,
+                    });
                 });
                 debug!("device removal: {:?} {:?}", handle, device.name);
             }
