@@ -1,6 +1,6 @@
 use std::path::{Path, PathBuf};
+use windows::core::PCWSTR;
 use windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
-use windows::core::{PCWSTR};
 
 #[inline]
 fn make_int_resource(id: u16) -> PCWSTR {
