@@ -16,11 +16,11 @@ use raw_window_handle::{HasRawWindowHandle, RawWindowHandle, Win32Handle};
 use std::cell::RefCell;
 use std::rc::Rc;
 use std::sync::{Arc, RwLock};
+use windows::core::PCWSTR;
 use windows::Win32::{
     Foundation::*, Graphics::Gdi::*, System::LibraryLoader::*, UI::HiDpi::*, UI::Shell::*,
     UI::WindowsAndMessaging::*,
 };
-use windows::core::PCWSTR;
 
 #[derive(Clone, PartialEq, Eq)]
 pub(crate) struct WindowHandle(HWND);
@@ -847,7 +847,8 @@ unsafe impl HasRawWindowHandle for Window {
     #[inline]
     fn raw_window_handle(&self) -> RawWindowHandle {
         let mut handle = Win32Handle::empty();
-        handle.hinstance = unsafe { GetModuleHandleW(PCWSTR::default()).0 as *mut std::ffi::c_void };
+        handle.hinstance =
+            unsafe { GetModuleHandleW(PCWSTR::default()).0 as *mut std::ffi::c_void };
         handle.hwnd = self.hwnd.0 .0 as *mut std::ffi::c_void;
         RawWindowHandle::Win32(handle)
     }
